

from __future__ import unicode_literals
from __future__ import print_function
from reahl.doc.examples.tutorial.parameterised2.parameterised2 import AddressBookUI

web.site_root = AddressBookUI
